[Libreoffice-commits] core.git: basic/source chart2/source connectivity/source cui/source dbaccess/source dmake/function.c filter/source fpicker/source framework/inc framework/source i18npool/inc officecfg/registry reportdesign/source sc/inc sc/source solenv/inc sw/source udkapi/com vcl/source

Julien Nabet serval2412 at yahoo.fr
Sat Feb 23 08:22:50 PST 2013


 basic/source/runtime/methods.cxx                                     |    2 -
 chart2/source/inc/ObjectIdentifier.hxx                               |    2 -
 connectivity/source/drivers/file/FStatement.cxx                      |    2 -
 cui/source/dialogs/iconcdlg.cxx                                      |    4 +-
 cui/source/inc/cuifmsearch.hxx                                       |    2 -
 dbaccess/source/ui/inc/UITools.hxx                                   |    2 -
 dmake/function.c                                                     |   16 +++++-----
 filter/source/config/cache/filtercache.hxx                           |    2 -
 filter/source/config/cache/querytokenizer.hxx                        |    2 -
 filter/source/config/tools/split/FCFGSplit.java                      |    2 -
 fpicker/source/win32/filepicker/filepickerstate.cxx                  |    2 -
 framework/inc/macros/debug/assertion.hxx                             |    2 -
 framework/inc/services/pathsettings.hxx                              |    2 -
 framework/source/fwe/classes/framelistanalyzer.cxx                   |    4 +-
 framework/source/fwe/xml/toolboxdocumenthandler.cxx                  |    2 -
 framework/source/jobs/joburl.cxx                                     |    2 -
 framework/source/services/frame.cxx                                  |    2 -
 i18npool/inc/xdictionary.hxx                                         |    2 -
 officecfg/registry/schema/org/openoffice/Office/WebWizard.xcs        |    2 -
 reportdesign/source/ui/inc/GeometryHandler.hxx                       |    4 +-
 sc/inc/chgtrack.hxx                                                  |    2 -
 sc/source/ui/vba/vbarange.cxx                                        |    2 -
 solenv/inc/tg_compv.mk                                               |    2 -
 solenv/inc/tg_javav.mk                                               |    2 -
 sw/source/ui/inc/gloslst.hxx                                         |    4 +-
 udkapi/com/sun/star/connection/XAcceptor.idl                         |    2 -
 udkapi/com/sun/star/connection/XConnector.idl                        |    2 -
 udkapi/com/sun/star/io/XTextInputStream.idl                          |    2 -
 udkapi/com/sun/star/reflection/XTypeDescriptionEnumerationAccess.idl |    2 -
 vcl/source/app/dbggui.cxx                                            |    8 ++---
 30 files changed, 44 insertions(+), 44 deletions(-)

New commits:
commit 3a014901fdc4134f4fae669b66b154b1137c2352
Author: Julien Nabet <serval2412 at yahoo.fr>
Date:   Sat Feb 23 17:20:45 2013 +0100

    Fix typo seperated/separated
    
    Change-Id: I133423de994b1befe246b6c921802428a3528202

diff --git a/basic/source/runtime/methods.cxx b/basic/source/runtime/methods.cxx
index d46d99b..af2f021 100644
--- a/basic/source/runtime/methods.cxx
+++ b/basic/source/runtime/methods.cxx
@@ -3417,7 +3417,7 @@ RTLFUNC(Shell)
         }
         sal_Int32 nLen = aCmdLine.getLength();
 
-        // #55735 if there are parameters, they have to be seperated
+        // #55735 if there are parameters, they have to be separated
         // #72471 also seperate the single parameters
         std::list<String> aTokenList;
         OUString aToken;
diff --git a/chart2/source/inc/ObjectIdentifier.hxx b/chart2/source/inc/ObjectIdentifier.hxx
index 58f6041..0c4b3c5 100644
--- a/chart2/source/inc/ObjectIdentifier.hxx
+++ b/chart2/source/inc/ObjectIdentifier.hxx
@@ -81,7 +81,7 @@ class OOO_DLLPUBLIC_CHARTTOOLS ObjectIdentifier
     //syntax of a CID:  CID:/classification/ObjectID
 
     //where classification: nothing or "MultiClick" or "DragMethod=DragMethodServiceName" and "DragParameter=DragParameterString"
-    //                      or a combination of these seperated with a colon
+    //                      or a combination of these separated with a colon
     //where DragMethodServiceName can be a selfdefined servicename for special actions //todo define standard service for this purpose
     //where DragParameterString is any string you like to transport information to your special drag service
     //                            only semicolon, colon, equal sign and slash are not allowed characters
diff --git a/connectivity/source/drivers/file/FStatement.cxx b/connectivity/source/drivers/file/FStatement.cxx
index 49c6046..4b4c886 100644
--- a/connectivity/source/drivers/file/FStatement.cxx
+++ b/connectivity/source/drivers/file/FStatement.cxx
@@ -563,7 +563,7 @@ void OStatement_Base::GetAssignValues()
 
         m_aParameterIndexes.resize(nCount+1,SQL_NO_PARAMETER);
 
-        // List of Column-Names, that exist in the column_commalist (seperated by ;):
+        // List of Column-Names, that exist in the column_commalist (separated by ;):
         ::std::vector<String> aColumnNameList;
 
         OSL_ENSURE(m_pParseTree->count() >= 4,"OResultSet: Fehler im Parse Tree");
diff --git a/cui/source/dialogs/iconcdlg.cxx b/cui/source/dialogs/iconcdlg.cxx
index 8c6feb0..12b2e50 100644
--- a/cui/source/dialogs/iconcdlg.cxx
+++ b/cui/source/dialogs/iconcdlg.cxx
@@ -685,7 +685,7 @@ IMPL_LINK_NOARG(IconChoiceDialog, ResetHdl)
 
     if ( pData->bOnDemand )
     {
-        // CSet on AIS has problems here, therefore seperated
+        // CSet on AIS has problems here, therefore separated
         const SfxItemSet* _pSet = &( pData->pPage->GetItemSet() );
         pData->pPage->Reset( *(SfxItemSet*)_pSet );
     }
@@ -845,7 +845,7 @@ void IconChoiceDialog::ResetPageImpl ()
 
     if ( pData->bOnDemand )
     {
-        // CSet on AIS has problems here, therefore seperated
+        // CSet on AIS has problems here, therefore separated
         const SfxItemSet* _pSet = &pData->pPage->GetItemSet();
         pData->pPage->Reset( *(SfxItemSet*)_pSet );
     }
diff --git a/cui/source/inc/cuifmsearch.hxx b/cui/source/inc/cuifmsearch.hxx
index 64cbd01..e5e3561 100644
--- a/cui/source/inc/cuifmsearch.hxx
+++ b/cui/source/inc/cuifmsearch.hxx
@@ -100,7 +100,7 @@ class FmSearchDialog : public ModalDialog
 
     ::svxform::FmSearchConfigItem*      m_pConfig;
 public:
-    /** This can search in different sets of fields. There is a number of contexts; their names are in strContexts (seperated
+    /** This can search in different sets of fields. There is a number of contexts; their names are in strContexts (separated
         by ';'), the user can choose one of them.
         When the user chooses a context, lnkContextSupplier is called, it gets a pointer on an FmSearchContext-structure,
         that has to be filled.
diff --git a/dbaccess/source/ui/inc/UITools.hxx b/dbaccess/source/ui/inc/UITools.hxx
index 5bec057..35350ed 100644
--- a/dbaccess/source/ui/inc/UITools.hxx
+++ b/dbaccess/source/ui/inc/UITools.hxx
@@ -114,7 +114,7 @@ namespace dbaui
 
     /** fills a map and a vector with localized type names
         @param  _rxConnection   the connection to acces the metadata
-        @param  _rsTypeNames    a list of localized type names seperated with ';'
+        @param  _rsTypeNames    a list of localized type names separated with ';'
         @param  _rTypeInfoMap   the filled map with the type names
         @param  _rTypeInfoIters the vector filled with map iterators
     */
diff --git a/filter/source/config/cache/filtercache.hxx b/filter/source/config/cache/filtercache.hxx
index 1448272..3473110 100644
--- a/filter/source/config/cache/filtercache.hxx
+++ b/filter/source/config/cache/filtercache.hxx
@@ -771,7 +771,7 @@ class FilterCache : public BaseLock
         /** @short      register the specified item for the given type.
 
             @descr      Because detect services, frame loader or content handler
-                        are not listed inside the xml configuration as seperated
+                        are not listed inside the xml configuration as separated
                         items (they are properties of any type entry!), this method update
                         the internal lists of such items. Thats neccessary to have
                         it accessible for our container interfaces of detect, frame loader
diff --git a/filter/source/config/cache/querytokenizer.hxx b/filter/source/config/cache/querytokenizer.hxx
index 30c5305..c7e45eb 100644
--- a/filter/source/config/cache/querytokenizer.hxx
+++ b/filter/source/config/cache/querytokenizer.hxx
@@ -72,7 +72,7 @@ class QueryTokenizer : public ::boost::unordered_map< ::rtl::OUString
                     a new query.
 
             @descr  The given query is immidiatly analyzed
-                    and seperated into its token, which can
+                    and separated into its token, which can
                     be access by some specialized method later.
 
             @param  sQuery
diff --git a/filter/source/config/tools/split/FCFGSplit.java b/filter/source/config/tools/split/FCFGSplit.java
index 8c37933..d9fda87 100644
--- a/filter/source/config/tools/split/FCFGSplit.java
+++ b/filter/source/config/tools/split/FCFGSplit.java
@@ -177,7 +177,7 @@ public class FCFGSplit
      *  Its meaned relative to m_sOutDir. */
     private static java.lang.String m_sSubDirContentHandlers;
 
-    /** enable/disable generating of filter groups - seperated by
+    /** enable/disable generating of filter groups - separated by
      *  application modules. */
     private static boolean m_bSeperateFiltersByModule;
 
diff --git a/fpicker/source/win32/filepicker/filepickerstate.cxx b/fpicker/source/win32/filepicker/filepickerstate.cxx
index 3684d4a..991f15a 100644
--- a/fpicker/source/win32/filepicker/filepickerstate.cxx
+++ b/fpicker/source/win32/filepicker/filepickerstate.cxx
@@ -655,7 +655,7 @@ inline sal_Bool SAL_CALL CExecuteFilePickerState::IsListboxControl( HWND hwndCon
 
 //---------------------------------------------
 // because listboxes (comboboxes) and their labels
-// are seperated we have to translate the listbox
+// are separated we have to translate the listbox
 // id to their corresponding label id
 // the convention is that the label id of a listbox
 // is the id of the listbox + 100
diff --git a/framework/inc/macros/debug/assertion.hxx b/framework/inc/macros/debug/assertion.hxx
index ba717e0..28988ec 100644
--- a/framework/inc/macros/debug/assertion.hxx
+++ b/framework/inc/macros/debug/assertion.hxx
@@ -183,7 +183,7 @@
         LOG_EXCEPTION( SMETHOD, SOWNMESSAGE, SEXCEPTIONMESSAGE )
 
         Show some exception info by using current set output mode by define LOGTYPE!
-        We use a seperated scope {} do protect us against multiple variable definitions.
+        We use a separated scope {} do protect us against multiple variable definitions.
     _____________________________________________________________________________________________________________*/
 
     #define LOG_EXCEPTION( SMETHOD, SOWNMESSAGE, SEXCEPTIONMESSAGE )                                            \
diff --git a/framework/inc/services/pathsettings.hxx b/framework/inc/services/pathsettings.hxx
index a5eb1f3..a947248 100644
--- a/framework/inc/services/pathsettings.hxx
+++ b/framework/inc/services/pathsettings.hxx
@@ -214,7 +214,7 @@ class PathSettings : public  css::lang::XTypeProvider             ,
                         sal_Bool                bReSubst);
 
 
-        /** converts our new string list schema to the old ";" seperated schema ... */
+        /** converts our new string list schema to the old ";" separated schema ... */
         ::rtl::OUString impl_convertPath2OldStyle(const PathSettings::PathInfo& rPath        ) const;
         OUStringList    impl_convertOldStyle2Path(const ::rtl::OUString&        sOldStylePath) const;
 
diff --git a/framework/source/fwe/classes/framelistanalyzer.cxx b/framework/source/fwe/classes/framelistanalyzer.cxx
index a223b3d..f5b6a05 100644
--- a/framework/source/fwe/classes/framelistanalyzer.cxx
+++ b/framework/source/fwe/classes/framelistanalyzer.cxx
@@ -179,7 +179,7 @@ void FrameListAnalyzer::impl_analyze()
 
             // -------------------------------------------------
             // a) Is it the special help task?
-            //    Return it seperated from any return list.
+            //    Return it separated from any return list.
             if (
                 ((m_eDetectMode & E_HELP) == E_HELP      ) &&
                 (xFrame->getName()==SPECIALTARGET_HELPTASK)
@@ -191,7 +191,7 @@ void FrameListAnalyzer::impl_analyze()
 
             // -------------------------------------------------
             // b) Or is includes this task the special backing component?
-            //    Return it seperated from any return list.
+            //    Return it separated from any return list.
             //    But check if the reference task itself is the backing frame.
             //    Our user mst know it to decide right.
             if ((m_eDetectMode & E_BACKINGCOMPONENT) == E_BACKINGCOMPONENT)
diff --git a/framework/source/fwe/xml/toolboxdocumenthandler.cxx b/framework/source/fwe/xml/toolboxdocumenthandler.cxx
index 7826ac2..017a041 100644
--- a/framework/source/fwe/xml/toolboxdocumenthandler.cxx
+++ b/framework/source/fwe/xml/toolboxdocumenthandler.cxx
@@ -366,7 +366,7 @@ throw(  SAXException, RuntimeException )
 
                             case TB_ATTRIBUTE_STYLE:
                             {
-                                // read space seperated item style list
+                                // read space separated item style list
                                 ::rtl::OUString aTemp = xAttribs->getValueByIndex( n );
                                 sal_Int32 nIndex = 0;
 
diff --git a/framework/source/jobs/joburl.cxx b/framework/source/jobs/joburl.cxx
index 3af88e4..2378e53 100644
--- a/framework/source/jobs/joburl.cxx
+++ b/framework/source/jobs/joburl.cxx
@@ -251,7 +251,7 @@ sal_Bool JobURL::implst_split( /*IN*/  const ::rtl::OUString& sPart           ,
     // Otherwhise we do nothing and return sal_False.
     if (bPartFound)
     {
-        // But may the part has optional arguments - seperated by a "?".
+        // But may the part has optional arguments - separated by a "?".
         // Do so - we set the return value with the whole part string.
         // Arguments will be set to an empty string as default.
         // If we detect the right sign - we split the arguments and overwrite the default.
diff --git a/framework/source/services/frame.cxx b/framework/source/services/frame.cxx
index 2a6639c..0919629 100644
--- a/framework/source/services/frame.cxx
+++ b/framework/source/services/frame.cxx
@@ -3083,7 +3083,7 @@ void Frame::impl_checkMenuCloser()
     // If there exist ate least one other frame - there are two frames currently open.
     // But we can enable this closer only, if one of these two tasks includes the help module.
     // The "other frame" couldn't be the help. Because then it wouldn't be part of this "other list".
-    // In such case it will be seperated to the reference aAnalyzer.m_xHelp!
+    // In such case it will be separated to the reference aAnalyzer.m_xHelp!
     // But we must check, if weself includes the help ...
     // Check aAnalyzer.m_bReferenceIsHelp!
     if (
diff --git a/i18npool/inc/xdictionary.hxx b/i18npool/inc/xdictionary.hxx
index fe90d7c..12cc908 100644
--- a/i18npool/inc/xdictionary.hxx
+++ b/i18npool/inc/xdictionary.hxx
@@ -32,7 +32,7 @@ namespace com { namespace sun { namespace star { namespace i18n {
 // cache structure.
 struct WordBreakCache {
     sal_Int32 length;       // contents length saved here.
-    sal_Unicode *contents;      // seperated segment contents.
+    sal_Unicode *contents;      // separated segment contents.
     sal_Int32* wordboundary;        // word boundaries in segments.
     sal_Int32 size;         // size of wordboundary
 
diff --git a/officecfg/registry/schema/org/openoffice/Office/WebWizard.xcs b/officecfg/registry/schema/org/openoffice/Office/WebWizard.xcs
index 5a9f54a..0b51520 100644
--- a/officecfg/registry/schema/org/openoffice/Office/WebWizard.xcs
+++ b/officecfg/registry/schema/org/openoffice/Office/WebWizard.xcs
@@ -473,7 +473,7 @@
 			</prop>
 			<prop oor:name="Filter" oor:type="xs:string">
 				<info>
-					<desc>Semicolon seperated list of file types this filter will show</desc>
+					<desc>Semicolon separated list of file types this filter will show</desc>
 				</info>
 			</prop>
 		</group>
diff --git a/reportdesign/source/ui/inc/GeometryHandler.hxx b/reportdesign/source/ui/inc/GeometryHandler.hxx
index b66c239..bdef435 100644
--- a/reportdesign/source/ui/inc/GeometryHandler.hxx
+++ b/reportdesign/source/ui/inc/GeometryHandler.hxx
@@ -145,13 +145,13 @@ namespace rptui
         */
         bool impl_isDataField(const ::rtl::OUString& _sName) const;
 
-        /**return all formula in a semicolon seperated list
+        /**return all formula in a semicolon separated list
         *
         * \param _rList the localized function names
         */
         void impl_fillFormulaList_nothrow(::std::vector< ::rtl::OUString >& _out_rList) const;
 
-        /** return all group names in a semicolon seperated list starting with the group where this control is contained in.
+        /** return all group names in a semicolon separated list starting with the group where this control is contained in.
         *
         * \param _rList fills the list with all scope names.
         */
diff --git a/sc/inc/chgtrack.hxx b/sc/inc/chgtrack.hxx
index 83228bd..4c94932 100644
--- a/sc/inc/chgtrack.hxx
+++ b/sc/inc/chgtrack.hxx
@@ -891,7 +891,7 @@ enum ScChangeTrackMergeState
 };
 
 // Internally generated actions start at this value (nearly all bits set)
-// and are decremented, to keep values in a table seperated from "normal" actions.
+// and are decremented, to keep values in a table separated from "normal" actions.
 #define SC_CHGTRACK_GENERATED_START ((sal_uInt32) 0xfffffff0)
 
 class ScChangeTrack : public utl::ConfigurationListener
diff --git a/sc/source/ui/vba/vbarange.cxx b/sc/source/ui/vba/vbarange.cxx
index 266f6b8..ab94414 100644
--- a/sc/source/ui/vba/vbarange.cxx
+++ b/sc/source/ui/vba/vbarange.cxx
@@ -1170,7 +1170,7 @@ bool getScRangeListForAddress( const rtl::OUString& sName, ScDocShell* pDocSh, S
     uno::Reference< beans::XPropertySet > xProps( pDocSh->GetModel(), uno::UNO_QUERY_THROW );
     uno::Reference< container::XNameAccess > xNameAccess( xProps->getPropertyValue( "NamedRanges" ), uno::UNO_QUERY_THROW );
     // Strangly enough you can have Range( "namedRange1, namedRange2, etc," )
-    // loop around each ',' seperated name
+    // loop around each ',' separated name
     std::vector< rtl::OUString > vNames;
     sal_Int32 nIndex = 0;
     do
diff --git a/solenv/inc/tg_compv.mk b/solenv/inc/tg_compv.mk
index 8036d0a..3630f78 100644
--- a/solenv/inc/tg_compv.mk
+++ b/solenv/inc/tg_compv.mk
@@ -58,7 +58,7 @@ CFLAGSNUMVERSION_CMD= -V  $(PIPEERROR) $(AWK) -v num=true -f $(SOLARENV)/bin/get
 CCVER:=$(shell @-$(CXX) $(CFLAGSVERSION_CMD))
 
 # and a computed integer for comparing
-# each point seperated token blown up to 4 digits
+# each point separated token blown up to 4 digits
 CCNUMVER:=$(shell @-$(CXX) $(CFLAGSNUMVERSION_CMD))
 
 .IF "$(COM)"=="MSC"
diff --git a/solenv/inc/tg_javav.mk b/solenv/inc/tg_javav.mk
index 6451b2f..2c56bb5 100644
--- a/solenv/inc/tg_javav.mk
+++ b/solenv/inc/tg_javav.mk
@@ -33,7 +33,7 @@ JFLAGSNUMVERSION_CMD=-version $(PIPEERROR) $(AWK) -v num=true -f $(SOLARENV)/bin
 JAVAVER:=$(shell @-$(JAVA_HOME)/bin/java $(JFLAGSVERSION_CMD))
 
 # and a computed integer for comparing
-# each point seperated token blown up to 4 digits
+# each point separated token blown up to 4 digits
 JAVANUMVER:=$(shell @-$(JAVA_HOME)/bin/java $(JFLAGSNUMVERSION_CMD))
 
 .ELSE          # "$(SOLAR_JAVA)"!=""
diff --git a/sw/source/ui/inc/gloslst.hxx b/sw/source/ui/inc/gloslst.hxx
index e0ccd23..9bc2c35 100644
--- a/sw/source/ui/inc/gloslst.hxx
+++ b/sw/source/ui/inc/gloslst.hxx
@@ -33,8 +33,8 @@ struct AutoTextGroup
     sal_uInt16      nCount;
     String      sName;
     String      sTitle;
-    String      sLongNames;   // by 0x0A seperated long names
-    String      sShortNames;  // by 0x0A seperated short names
+    String      sLongNames;   // by 0x0A separated long names
+    String      sShortNames;  // by 0x0A separated short names
     DateTime    aDateModified;
 
     AutoTextGroup() : aDateModified( DateTime::EMPTY ) {}
diff --git a/udkapi/com/sun/star/connection/XAcceptor.idl b/udkapi/com/sun/star/connection/XAcceptor.idl
index baf8c82..367fffb 100644
--- a/udkapi/com/sun/star/connection/XAcceptor.idl
+++ b/udkapi/com/sun/star/connection/XAcceptor.idl
@@ -43,7 +43,7 @@ published interface XAcceptor: com::sun::star::uno::XInterface
 
        @param sConnectionDescription
                 contains the kind of the connection plus a
-              comma seperated list of attributes,
+              comma separated list of attributes,
                e.g., <em>socket,host=localhost,port=2345</em> for a tcpip connection.
 
        @return null reference,
diff --git a/udkapi/com/sun/star/connection/XConnector.idl b/udkapi/com/sun/star/connection/XConnector.idl
index e841d9c..4e4c714 100644
--- a/udkapi/com/sun/star/connection/XConnector.idl
+++ b/udkapi/com/sun/star/connection/XConnector.idl
@@ -42,7 +42,7 @@ published interface XConnector: com::sun::star::uno::XInterface
 
         @param sConnectionDescription
                 contains the kind of the connection plus a
-                comma seperated list of attributes,
+                comma separated list of attributes,
                e.g., <em>socket,host=locahost,port=2345</em> for a tcpip connection.
 
         @throws ConnectionSetupException
diff --git a/udkapi/com/sun/star/io/XTextInputStream.idl b/udkapi/com/sun/star/io/XTextInputStream.idl
index a84c10f..622f152 100644
--- a/udkapi/com/sun/star/io/XTextInputStream.idl
+++ b/udkapi/com/sun/star/io/XTextInputStream.idl
@@ -29,7 +29,7 @@ module com {  module sun {  module star {  module io {
 
 /** Interface to read strings from a stream.
 
-    <p>This interfaces allows to read strings seperated by
+    <p>This interfaces allows to read strings separated by
     delimiters and to read lines. The character encoding
     to be used can be set by <member>setEncoding()</member>.
     Default encoding is "utf8".</p>
diff --git a/udkapi/com/sun/star/reflection/XTypeDescriptionEnumerationAccess.idl b/udkapi/com/sun/star/reflection/XTypeDescriptionEnumerationAccess.idl
index 73eaa9e..fba9817 100644
--- a/udkapi/com/sun/star/reflection/XTypeDescriptionEnumerationAccess.idl
+++ b/udkapi/com/sun/star/reflection/XTypeDescriptionEnumerationAccess.idl
@@ -47,7 +47,7 @@ published interface XTypeDescriptionEnumerationAccess : com::sun::star::uno::XIn
         for the search within the underlying type description tree.
 
         @param moduleName
-            contains the name of an UNOIDL module. Modules are seperated by a
+            contains the name of an UNOIDL module. Modules are separated by a
             single '.' (i.e., "com.sun.star.reflection"). The root of the module
             hierarchy is specified with an empty string. Module names are always
             absolute, never relative.
diff --git a/vcl/source/app/dbggui.cxx b/vcl/source/app/dbggui.cxx
index c6d1af8..22051aa 100644
--- a/vcl/source/app/dbggui.cxx
+++ b/vcl/source/app/dbggui.cxx
@@ -197,25 +197,25 @@ static const sal_Char* pDbgHelpText[] =
 "\n",
 "Include ObjectTest filters\n",
 "Only classes which contain one of the indicated filters are evaluated with "
-"the object test. Filters are seperated by ';' and are case sensitive. "
+"the object test. Filters are separated by ';' and are case sensitive. "
 "Wildcards are not supported. If no text is indicated the filters are not "
 "active.\n",
 "\n",
 "Exclude ObjectTest filters\n",
 "Only classes which do not contain one of the indicated filters are evaluated "
-"with the object test. Filters are seperated by ';' and are case sensitive. "
+"with the object test. Filters are separated by ';' and are case sensitive. "
 "Wildcards are not supported. If no text is indicated the filters are not "
 "active.\n",
 "\n",
 "Include filters\n",
 "Only those texts which include the indicated filters are output. "
-"Filters are seperated by ';' and are case sensitive. "
+"Filters are separated by ';' and are case sensitive. "
 "Wildcards are not supported. The filter is used for all output (except for "
 "errors). If no text is indicated the filters are not active.\n",
 "\n",
 "Exclude filters\n",
 "Only those texts which do not include the indicated filters are output. "
-"Filters are seperated by ';' and are case sensitive. "
+"Filters are separated by ';' and are case sensitive. "
 "Wildcards are not supported. The filter is used for all output (except for "
 "errors). If no text is indicated the filters are not active.\n",
 "\n",


More information about the Libreoffice-commits mailing list
diff --git a/dmake/function.c b/dmake/function.c
index 0fcc688..ac8c0b4 100644
--- a/dmake/function.c
+++ b/dmake/function.c
@@ -78,7 +78,7 @@ char *buf;
       }
    }
 
    /* ??? Some function macros expect comma seperated parameters, but
     * no decent parser is included. The desirable solution would be
     * to parse fname for the correct number of parameters in fname
     * when a function is recognized. We only count the parameters
@@ -113,7 +113,7 @@ char *buf;
         if( mod_count == 2 )
           res = _exec_iseq(mod1,mod2,args,TRUE);
         else
-          Fatal( "Two comma-seperated arguments expected in [%s].\n", buf );
+          Fatal( "Two comma-separated arguments expected in [%s].\n", buf );
      else if (strncmp(fname,"echo",4) == 0)
         res = _exec_echo(args);
          else
@@ -125,7 +125,7 @@ char *buf;
         if( mod_count == 2 )
           res = _exec_foreach(mod1,mod2,args);
         else
-          Fatal( "Two comma-seperated arguments expected in [%s].\n", buf );
+          Fatal( "Two comma-separated arguments expected in [%s].\n", buf );
      else
         res = _exec_call(fname,args);
      break;
@@ -135,7 +135,7 @@ char *buf;
         if( mod_count < 3 )
           res = _exec_mktmp(mod1,mod2,args);
         else
-          Fatal( "Maximal two comma-seperated arguments expected in [%s].\n", buf );
+          Fatal( "Maximal two comma-separated arguments expected in [%s].\n", buf );
      else
         res = _exec_call(fname,args);
      break;
@@ -169,7 +169,7 @@ char *buf;
            FREE(para);
         }
         else
-           Fatal( "One or no comma-seperated arguments expected in [%s].\n", buf );
+           Fatal( "One or no comma-separated arguments expected in [%s].\n", buf );
 
         FREE(eargs);
      }
@@ -184,7 +184,7 @@ char *buf;
         if( mod_count == 2 )
           res = _exec_iseq(mod1,mod2,args,FALSE);
         else
-          Fatal( "Two comma-seperated arguments expected in [%s].\n", buf );
+          Fatal( "Two comma-separated arguments expected in [%s].\n", buf );
      else
         res = _exec_call(fname,args);
      break;
@@ -212,14 +212,14 @@ char *buf;
            FREE(emod);
         }
         else
-           Fatal( "One or no comma-seperated arguments expected in [%s].\n", buf );
+           Fatal( "One or no comma-separated arguments expected in [%s].\n", buf );
      else if(strncmp(fname,"strip",5)==0)
         res = Tokenize(Expand(args)," ",'t',TRUE);
      else if(strncmp(fname,"subst",5)==0) {
         if( mod_count == 2 )
           res = _exec_subst(mod1,mod2,args);
         else
-          Fatal( "Two comma-seperated arguments expected in [%s].\n", buf );
+          Fatal( "Two comma-separated arguments expected in [%s].\n", buf );
      }
          else
             res = _exec_call(fname,args);
@@ -78,7 +78,7 @@ char *buf;
    }
 
-   /* ??? Some function macros expect comma seperated parameters, but
+   /* ??? Some function macros expect comma separated parameters, but
     * no decent parser is included. The desirable solution would be
     * to parse fname for the correct number of parameters in fname